import os
import re
import argparse

from glob import glob


class ParseDemArgs:

    @staticmethod
    def parse():
        parser = argparse.ArgumentParser(description='Eco Beta 9.4.1 - Change Stack Size for Eco Items and Stock Piles - PLEASE NOTE THE DOUBLE SLASH IN THE PATH')
        parser.add_argument('-m', '--multipler', type=int, help='Mutiply the default stack size, DEFAULT 2', default=2)
        parser.add_argument('-e', '--eco', type=str, help='Path to Eco Mods Folder, DEFAULT C:\\\\Program Files (x86)\\\\Steam\\\\steamapps\\\\common\\\\Eco\\\\Eco_Data\\\\Server\\\Mods\\\\__core__\\\\', default='C:\\Program Files (x86)\\Steam\\steamapps\\common\\Eco\\Eco_Data\\Server\\Mods\\__core__\\')
        parser.add_argument('-f', '--folder', type=str, help='Path to new folder to save modified files, DEFAULT = C:\\\\Temp\\\\Eco\\\\mods\\\\riverdale_stack_size\\\\', default='C:\\Temp\\Eco\\mods\\riverdale_stack_size\\')
        return parser.parse_args()


class ModEco:

    def __init__(self, main_folder: str, mod_folder: str, stack_size_multipler: int):
        self.main_folder = main_folder
        self.sub_folders = [
            'AutoGen\\Block\\',
            'AutoGen\\Fertilizer\\',
            'AutoGen\\Food\\',
            'AutoGen\\Item\\',
            'AutoGen\\Seed\\',
            'Items\\',
            'Objects\\'
        ]
        self.storage_objects = [
            'LargeLumberStockpileObject.cs',
            'LumberStockpileObject.cs',
            'SmallStockpileObject.cs',
            'StockpileObject.cs',
            'StorageChestObject.cs',
            'TinyStockpileObject.cs'
        ]
        self.stack_size_multipler = stack_size_multipler
        self.mod_folder = mod_folder

    def modify(self):
        print("Files will be saved to: {}".format(self.mod_folder))
        print("Reading files from: {}\n".format(self.main_folder))
        for sub_folder in self.sub_folders:
            print("Reading files from: {}".format(sub_folder))
            if not os.path.isdir("{}{}".format(self.mod_folder, sub_folder)):
                os.makedirs("{}{}".format(self.mod_folder, sub_folder))
            for m_file in self.file_list("{}{}".format(self.main_folder, sub_folder)):
                print("Reading: {}".format(os.path.basename(m_file)))
                modified_file_contents = self.modify_stack_size(self.read_file(m_file))
                base_filename = os.path.splitext(os.path.basename(m_file))[0]
                filename_ext = os.path.splitext(os.path.basename(m_file))[1]
                self.write_file(modified_file_contents, "{}{}{}.override{}".format(self.mod_folder, sub_folder, base_filename, filename_ext))

    def modify_stack_size(self, file_contents: list):
        mod_file_contents = []
        for line in file_contents:
            if '[MaxStackSize(' in line:
                print("\tOld Stack Size: {}".format(re.findall(r'\d+', line)[0]))
                print("\tNew Stack Size: {}".format(int(re.findall(r'\d+', line)[0]) * self.stack_size_multipler))
                line = line.replace(re.findall(r'\d+', line)[0],
                                    str(int(re.findall(r'\d+', line)[0]) * self.stack_size_multipler))
            elif 'new StockpileStackRestriction(DefaultDim.y)' in line:
               line = line.replace('DefaultDim.y', "DefaultDim.y * {}".format(self.stack_size_multipler))
            mod_file_contents.append(line)
        return mod_file_contents

    @staticmethod
    def file_list(folder: str):
        for mod_file in glob('{}*'.format(folder)):
            yield mod_file

    @staticmethod
    def read_file(file_path: str):
        file_contents = []
        with open(file_path, 'r') as m_file:
            for line in m_file.readlines():
                file_contents.append(line.replace('\n', ''))
        return file_contents

    @staticmethod
    def write_file(file_contents: list, file_to_write: str):
        with open(file_to_write, 'w') as ftw:
            ftw.write('\n'.join(file_contents))


if __name__ == '__main__':
    arguments = ParseDemArgs().parse()
    mod_eco = ModEco(arguments.eco, arguments.folder, arguments.multipler)
    mod_eco.modify()
